<?php

namespace Drupal\file_compressor_field\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings of provider for archive.
 */
class FileCompressorSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'file_compressor_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'file_compressor_field.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['zip_type_provider'] = [
      '#type' => 'radios',
      '#title' => $this->t('Choose the method for creating ZIP archives:'),
      '#config_target' => 'file_compressor_field.settings:field_zip_method',
      '#options' => [
        'php' => $this->t("PHP ZipArchive class. This method uses PHP's built-in ZipArchive class for creating ZIP archives."),
        'system' => $this->t("System 'zip' command. This method utilizes the system's 'zip' command for creating ZIP archives."),
      ],
      '#default_value' => $this->configFactory()
        ->getEditable('file_compressor_field.settings')
        ->get('field_zip_method') ?? 'php',
      '#required' => TRUE,
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save configuration'),
      '#button_type' => 'primary',
    ];

    $form['gzip_type_provider'] = [
      '#type' => 'radios',
      '#title' => $this->t('Choose the method for creating GZIP archives:'),
      '#config_target' => 'file_compressor_field.settings:field_gzip_method',
      '#options' => [
        'php' => $this->t("PHP Archive_Tar class. This method uses PHP's built-in Archive_Tar class for creating TAR archives."),
        'system' => $this->t("System 'tar' command. This method utilizes the system's 'tar' command for creating TAR archives."),
      ],
      '#default_value' => $this->configFactory()
        ->getEditable('file_compressor_field.settings')
        ->get('field_gzip_method') ?? 'php',
      '#required' => TRUE,
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save configuration'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory()
      ->getEditable('file_compressor_field.settings')
      ->set('field_zip_method', $form_state->getValue('zip_type_provider'))
      ->save();
    $this->configFactory()
      ->getEditable('file_compressor_field.settings')
      ->set('field_gzip_method', $form_state->getValue('gzip_type_provider'))
      ->save();
  }

}
